[![Codacy Badge](https://api.codacy.com/project/badge/Grade/3dbc32af83244f1fba8961cfe059ae37)](https://www.codacy.com/app/jlgelpi/structure_manager?utm_source=mmb.irbbarcelona.org&amp;utm_medium=referral&amp;utm_content=gitlab/BioExcel/structure_manager&amp;utm_campaign=Badge_Grade)

### Structure Manager package
Python package to manage 3D structures. Wraps Bio.PDB with additional features.

## Dependencies:
* python3.6
* Bio.PDB (Biopython 1.73)
* numpy
